"""MongoDB DAO Package

Module Poem
-----------

I came up once and hollered!
I came up twice and cried!
If that water hadn't a-been so cold
I might've sunk and died.

But it was Cold in that water! It was cold!

- Langston Hughes (Life is fine)
"""


from geocsvlib.dao.mongodb.ip_geolocation import IPGeolocation
