"""SQLite DAO Package

Module Poem
-----------

Oh whence do you come, my dear friend, to me,
With your golden hair all fallen below your knee,
And your face as white as snowdrops on the lea,
And your voice as hollow as the hollow sea?

- Christina Rosseti (The Poor Ghost)
"""


from geocsvlib.dao.sqlite.ip_geolocation import IPGeolocation
