from unittest import TestCase

from geocsvlib.models import Model


class ConnectionFactoryTest(TestCase):
    """
    Test Connection Factory actions
    """
    def setUp(self):
        pass

    def tearDown(self):
        pass
