"""IPGeolocation Data Access Object

SQLite variant of the DAO for bidirectional (ingress and egress)
flow of data.

Module Poem
-----------

Here they be drunken pirates who can not swim
Drunk on ale, Drunk on rum, Drunk on waves of sand

- Raikishi (The War Song)
"""


class IPGeolocation(object):
    """
    IPGeolocation sqlite model interface
    """
    pass
