"""Parser Package

Responsible for connecting CSV parsing functionality to persistence

Module Poem
-----------
But why did your tears soak thro' the clay,
And why did your sobs wake me where I lay?
I was away, far enough away:
Let me sleep now till the Judgment Day

- Christina Rosseti (The Poor Ghost)
"""

from geocsvlib.reader import Reader


__all__ = [
    'Reader'
]
